Absent

Enum Absent 

pub enum Absent {
    Repeater(Box<Expr>),
    Expression {
        absent: Box<Expr>,
        exp: Box<Expr>,
    },
    Stopper(Box<Expr>),
    Clear,
}
Type of absent operator as used for Oniguruma’s absent functionality.

Variants



Repeater(Box<Expr>)

Absent repeater (?~absent) - works like \O* (match any character including newline, repeated) but is limited by the range that does not include the string match with absent. This is a written abbreviation of (?~|absent|\O*).



Expression

Absent expression (?~|absent|exp) - works like exp, but is limited by the range that does not include the string match with absent.

Fields

absent: Box<Expr>

The expression to avoid matching

exp: Box<Expr>

The expression to match



Stopper(Box<Expr>)

Absent stopper (?~|absent) - after this operator, haystack range is limited up to the point where absent matches.



Clear

Range clear (?~|) - clears the effects caused by absent stoppers.