Assertion

Enum Assertion 

pub enum Assertion {
    StartText,
    EndText,
    EndTextIgnoreTrailingNewlines {
        crlf: bool,
    },
    StartLine {
        crlf: bool,
    },
    StartLineOniguruma {
        crlf: bool,
    },
    EndLine {
        crlf: bool,
    },
    LeftWordBoundary,
    LeftWordHalfBoundary,
    RightWordBoundary,
    RightWordHalfBoundary,
    WordBoundary,
    NotWordBoundary,
}
Type of assertions

Variants



StartText

Start of input text



EndText

End of input text



EndTextIgnoreTrailingNewlines

End of input text, or before any trailing newlines at the end (Oniguruma’s \Z)

Fields

crlf: bool

Whether CRLF mode is enabled. If true, trailing \r\n pairs (in addition to bare \n) are also ignored.



StartLine

Start of a line

Fields

crlf: bool

CRLF mode. If true, this assertion matches at the starting position of the input text, or at the position immediately following either a \r or \n character, but never after a \r when a \n follows.



StartLineOniguruma

Start of a line in Oniguruma mode. Behaves like Assertion::StartLine, but additionally rejects matches at the end of the input when it is preceded by a newline.

Fields

crlf: bool

CRLF mode. If true, this assertion matches at the starting position of the input text, or at the position immediately following either a \r or \n character, but never after a \r when a \n follows.



EndLine

End of a line

Fields

crlf: bool

CRLF mode If true, this assertion matches at the ending position of the input text, or at the position immediately preceding either a \r or \n character, but never after a \r when a \n follows.



LeftWordBoundary

Left word boundary



LeftWordHalfBoundary

Left word half boundary



RightWordBoundary

Right word boundary



RightWordHalfBoundary

Right word half boundary



WordBoundary

Both word boundaries



NotWordBoundary

Not word boundary