RegexSetMatch

Struct RegexSetMatch 

pub struct RegexSetMatch<'t, S: Input + ?Sized> { /* private fields */ }
A match from a RegexSet, including the pattern index and capture groups.

This type represents a single match found by a RegexSet. It provides information about which pattern matched, the location of the match, and access to any capture groups.

Examples

use fancy_regex::{RegexInput, RegexSet};

let set = RegexSet::new(&[r"\w+"])?;
let mut matches = set
    .find_input(RegexInput::new("abc"))?
    .expect("expected at least one match");

let m = matches.next().expect("expected first match")?;
assert_eq!(m.pattern(), 0);
assert_eq!(m.get().as_str(), "abc");
assert_eq!(m.start(), 0);
assert_eq!(m.end(), 3);
assert_eq!(m.captures().len(), 1);

Implementations

Source

impl<'t, S: Input + ?Sized> RegexSetMatch<'t, S>

pub fn pattern(&self) -> usize

Returns the pattern index that matched.

pub fn captures(&self) -> &Captures<'t, S>

Returns the full set of capture groups for this match.

pub fn get(&self) -> S::Match<'t>

Returns the full match.

pub fn start(&self) -> usize

Returns the start offset of the full match.

pub fn end(&self) -> usize

Returns the end offset of the full match.

Source

impl<'t> RegexSetMatch<'t, str>

pub fn as_str(&self) -> &'t str

Returns the matched text.