pub struct RegexSetOptions { /* private fields */ }Expand description
Configuration for a RegexSet
Implementations
Sourceimpl RegexSetOptions
impl RegexSetOptions
Sourcepub fn delegate_size_limit(self, limit: usize) -> Self
pub fn delegate_size_limit(self, limit: usize) -> Self
Set the approximate size limit of each delegated sub-regex.
This option is forwarded from the wrapped regex crate. Note that depending on the used
regex features there may be multiple delegated sub-regexes fed to the regex crate. As
such the actual limit is closer to <number of delegated regexes> * delegate_size_limit.
Sourcepub fn delegate_dfa_size_limit(self, limit: usize) -> Self
pub fn delegate_dfa_size_limit(self, limit: usize) -> Self
Set the approximate size of the cache used by delegated DFAs.
This option is forwarded from the wrapped regex crate. Note that depending on the used
regex features there may be multiple delegated sub-regexes fed to the regex crate. As
such the actual limit is closer to <number of delegated regexes> * delegate_dfa_size_limit.
Sourcepub fn meta_nfa_size_limit(self, limit: Option<usize>) -> Self
pub fn meta_nfa_size_limit(self, limit: Option<usize>) -> Self
Set the approximate NFA size limit for the regex-automata meta regex used to find the earliest match position.
Passing None disables the limit. The default is 64 MiB.
Sourcepub fn meta_hybrid_cache_capacity(self, limit: usize) -> Self
pub fn meta_hybrid_cache_capacity(self, limit: usize) -> Self
Set the cache capacity, in bytes, for the lazy DFA used by the regex-automata meta regex that finds the earliest match position.
The default is 64 MiB.
Sourcepub fn overlapping_dfa_cache_capacity(self, limit: usize) -> Self
pub fn overlapping_dfa_cache_capacity(self, limit: usize) -> Self
Set the cache capacity, in bytes, for the lazy DFA used to find overlapping matches at a candidate match position.
The default is 64 MiB.
Sourcepub fn overlapping_dfa_skip_cache_capacity_check(self, yes: bool) -> Self
pub fn overlapping_dfa_skip_cache_capacity_check(self, yes: bool) -> Self
Configure whether the overlapping DFA builder should skip its minimum cache capacity check.
Enabling this can allow large DFAs to build when the default cache capacity check would
reject them, but it may allocate more memory at build time. The default is true.