AstNode

Enum AstNode 

pub enum AstNode {
    AstGroup {
        name: Option<String>,
        inner: Box<Expr>,
    },
    Backref {
        target: CaptureGroupTarget,
        casei: bool,
        relative_recursion_level: Option<isize>,
    },
    SubroutineCall(CaptureGroupTarget),
    BackrefExistsCondition {
        target: CaptureGroupTarget,
        relative_recursion_level: Option<isize>,
    },
}
Abstract Syntax Tree node - will be resolved into an Expr before analysis

Variants



AstGroup

Group with optional name - name is only present if explicitly specified in pattern

Fields

name: Option<String>

Optional name of the capture group, present only when explicitly named in the pattern

inner: Box<Expr>

The inner expression of the group



Backref

Backreference

Fields

target: CaptureGroupTarget

The target capture group being referenced

casei: bool

Whether the matching is case-insensitive or not

relative_recursion_level: Option<isize>

Optional relative recursion level for the backreference



SubroutineCall(CaptureGroupTarget)

Subroutine Call



BackrefExistsCondition

Backreference exists condition (?(name)...) or (?(1)...) - unresolved target. The optional relative_recursion_level corresponds to the Oniguruma +N/-N suffix (e.g. (?(name+0)...)) which qualifies which recursion level’s capture is tested.

Fields

target: CaptureGroupTarget

The target capture group being tested for existence

relative_recursion_level: Option<isize>

Optional relative recursion level qualifier (e.g. +0, -1)