RegexBuilder

Struct RegexBuilder 

pub struct RegexBuilder { /* private fields */ }
A builder for a Regex to allow configuring options.

Implementations

Source

impl RegexBuilder

pub fn new(pattern: &str) -> Self

Create a new regex builder.

pub fn build(&self) -> Result<Regex>

Build a Regex from the given pattern.

Returns an Error if the pattern could not be parsed.

pub fn pattern(&mut self, pattern: String) -> &mut Self

Change the pattern to build. Useful when building multiple regexes from many patterns.

pub fn case_insensitive(&mut self, yes: bool) -> &mut Self

pub fn multi_line(&mut self, yes: bool) -> &mut Self

pub fn ignore_whitespace(&mut self, yes: bool) -> &mut Self

pub fn dot_matches_new_line(&mut self, yes: bool) -> &mut Self

pub fn verbose_mode(&mut self, yes: bool) -> &mut Self

pub fn unicode_mode(&mut self, yes: bool) -> &mut Self

pub fn backtrack_limit(&mut self, limit: usize) -> &mut Self

pub fn delegate_size_limit(&mut self, limit: usize) -> &mut Self

pub fn delegate_dfa_size_limit(&mut self, limit: usize) -> &mut Self

pub fn oniguruma_mode(&mut self, yes: bool) -> &mut Self

pub fn crlf(&mut self, yes: bool) -> &mut Self

pub fn find_not_empty(&mut self, yes: bool) -> &mut Self

pub fn ignore_numbered_groups_when_named_groups_exist( &mut self, yes: bool, ) -> &mut Self