pub struct RegexSetMatch<'t, S: Input + ?Sized> { /* private fields */ }Expand description
A match from a RegexSet, including the pattern index and capture groups.
This type represents a single match found by a RegexSet. It provides
information about which pattern matched, the location of the match, and
access to any capture groups.
Examples
use fancy_regex::{RegexInput, RegexSet};
let set = RegexSet::new(&[r"\w+"])?;
let mut matches = set
.find_input(RegexInput::new("abc"))?
.expect("expected at least one match");
let m = matches.next().expect("expected first match")?;
assert_eq!(m.pattern(), 0);
assert_eq!(m.get().as_str(), "abc");
assert_eq!(m.start(), 0);
assert_eq!(m.end(), 3);
assert_eq!(m.captures().len(), 1);Implementations